package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````,!@``#0````HP0```````#0`(``)
M`"@`'``;``8````T````-````#0````@`0``(`$```4````$`````P```%0!
M``!4`0``5`$``!,````3````!`````$````!````````````````````)*X`
M`"2N```%`````!````$```"@O0``H,T``*#-``!P`@``M!(```8`````$```
M`@```*R]``"LS0``K,T``"`!```@`0``!@````0````$````:`$``&@!``!H
M`0``1````$0````$````!````%#E=&1DGP``9)\``&2?``#T````]`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DH+T`
M`*#-``"@S0``8`(``&`"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@```"`````$````%`````,```!'
M3E4`XZK`;;TKR+J-<JN;"W^VZB*S_9X1````3`````@````(`````!`0!"5`
M!(`H`0`!H(8`@(`!```+*`0).*`218H$"`@`````3````%````!4````50``
M`%L```!<````70```%\```!@`````````&(```!D````90```&8`````````
M`````&[%WQ_JT^\.SMY'+6M_FGPNQ9NV(/_D#KB-\0[59-1\V7%8'.)'Q@&L
M2^/`NN.2?,+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'<-,-%.*>VLWCGC-B
MV^T,.I<+6>CM['^IG)OAIP(*H^#[20````````````````````"^`@``````
M```````2````;`,`````````````$@```!,"`````````````!(````1````
M```````````@````A0,`````````````$0```/D#`````````````!(````+
M`P`````````````1````70,`````````````$@```"4!`````````````!(`
M``#9`@`````````````2````R```````````````$@```)<!````````````
M`!(```#%`@`````````````2````F```````````````$@```"`!````````
M`````!(```"/`P`````````````2````$@,`````````````$@```!4!````
M`````````!$```"-`@`````````````2````>P$`````````````$@```/<`
M`````````````!$````9`P`````````````2````20$`````````````$@``
M`-8``````````````!(```!``P`````````````B````Q0$`````````````
M$@```%P"`````````````!(````+`@`````````````2````J0(`````````
M````$@```+(!`````````````!(```":`@`````````````2````O@$`````
M````````$@```%<!`````````````!(````B`P`````````````2````+0``
M````````````(````&X"`````````````!(```#0`0`````````````1````
M+P,`````````````$@```'@``````````````!(```"W`@`````````````2
M````<P,`````````````$@````0"`````````````!(```"G````````````
M```2````LP``````````````$@```'`!`````````````!(```"4`@``````
M```````2````>P(`````````````$@```#8!`````````````!(````L`@``
M```````````2````H@(`````````````$@```&H``````````````!(````J
M`0`````````````2````X`(`````````````$@```*<!`````````````!(`
M```$`0`````````````2````90,`````````````$@```+`"````````````
M`!(```"&`P`````````````A````B0$`````````````$@```(<`````````
M`````!(````\```````````````@````Z```````````````$@```&<!````
M`````````!(````V`P`````````````2````RP(`````````````$@```%``
M`````````````"````!S`@`````````````2````AP,`````````````$0``
M``$#`````````````!(````8`@`````````````2````[@(`````````````
M$@```#T"`````````````!(```"$`@`````````````2````^0(`````````
M````$@```$\#`````````````!(````"!```T%X``'L````2``X`T`,``!1@
M````````$@`/`"<$```@3@``*0T``!(`#@"``P``\!4``$`"```2``X`U@,`
M`&!'```%````$@`.`(T$``!P1P``'0(``!(`#@"'!```[!$````````2``L`
MN@0``%!;``"``P``$@`.`+4#```0T````````!``&0`.!```D$D``"(````2
M``X`30(``"Q@```$````$0`0`,$#``!4X````````!``&0"%!```\$4``#L`
M```2``X`F@0``$!-``#8````$@`.`*P$``"`3```>0```!(`#@`T!````-``
M```````0`!@`&P0``,!)``#L````$@`.`*X#```0T````````!``&`!G!```
M#-````0````1`!@`Q@,``/!?```"````$@`.`%<$``"07P``70```!(`#@`Z
M!```,!@````````2``X`-@0```#0````````(``8`'$$```H8```!````!$`
M$`#G`P```$T``#0````2``X`000``)!&``#)````$@`.`'@$``"P2@``R0$`
M`!(`#@``;&EB<&5R;"YS;RXU+C(V`%])5$U?9&5R96=I<W1E<E1-0VQO;F54
M86)L90!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?
M<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I
M;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T
M7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S
M=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?
M;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V
M7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L+G-O+C(`
M;&EB;2YS;RXV`&QI8G!T:')E860N<V\N,`!O<&5N-C0`;'-E96LV-`!R96%D
M`'!T:')E861?9V5T<W!E8VEF:6,`7U]E<G)N;U]L;V-A=&EO;@!C;&]S90!L
M:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A=&9O<FL`97AI
M=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`'5N;&EN:P!M:V1I<@!R96%L
M;&]C`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!S=')S='(`<FUD:7(`
M7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T
M`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A9&QI;FL`7U]M
M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S
M<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T
M7VUA:6X`7U]E;G9I<F]N`%]?<W1A8VM?8VAK7V9A:6P`;&EB8W)Y<'0N<V\N
M,0!?961A=&$`7U]B<W-?<W1A<G0`7V5N9`!?7VQI8F-?8W-U7V9I;FD`<&%R
M7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?
M8VQE86YU<`!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER
M`%]?9&%T85]S=&%R=`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S
M=5]I;FET`&UY7W!A<E]P;`!?9G!?:'<`<&%R7VEN:71?96YV`'AS7VEN:70`
M<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`
M6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N,@!'3$E"0U\R+C``1TQ)
M0D-?,BXS+C0`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXQ+C,`1TQ)0D-?,BXT````
M`@`"``,````"``(``@`"``(``@```````@``````!``"`````@```````@``
M````!0````8`!P`"`````@`"````"`````(````"`````@`"``<`````````
M`@`"`````P`"```````(```````"``(``@``````````````"0`(`````@`"
M``D``P`)``,``@`"``@``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`"`/0!```0````,````!)I:0T`
M``<`T`0``!`````0:6D-```#`-H$`````````0`&`$,"```0`````````!)I
M:0T```D`T`0``!````!T&6D)```(`.0$```0````<AEI"0``!@#P!```$```
M`',?:0D```4`_`0``!`````4:6D-```$``@%```0````$&EI#0```@#:!```
M`````*#-```(````I,T```@```#LSP``"`````30```(````#-````@```#(
MSP``!@0``,S/```&!P``T,\```8,``#4SP``!A(``-C/```&%0``W,\```89
M``#@SP``!B,``.3/```&)0``Z,\```8P``#PSP``!CP``/3/```&/0``^,\`
M``9"``#\SP``!D0``-C.```'`0``W,X```<"``#@S@``!P,``.3.```'!@``
MZ,X```<(``#LS@``!PD``/#.```'"@``],X```<+``#XS@``!PT``/S.```'
M#@```,\```</```$SP``!Q````C/```'$0``#,\```<3```0SP``!Q0``!3/
M```'%@``&,\```<7```<SP``!Q@``"#/```'&@``),\```<;```HSP``!QP`
M`"S/```''0``,,\```<>```TSP``!Q\``#C/```'(```/,\```<A``!`SP``
M!R(``$3/```')```2,\```<F``!,SP``!R<``%#/```'*```5,\```<I``!8
MSP``!RH``%S/```'*P``8,\```<L``!DSP``!RT``&C/```'+@``;,\```<O
M``!PSP``!S$``'3/```',@``>,\```<S``!\SP``!S0``(#/```'-0``A,\`
M``<V``"(SP``!S<``(S/```'.```D,\```<Y``"4SP``!SL``)C/```'/@``
MG,\```<_``"@SP``!T```*3/```'00``J,\```=#``"LSP``!T4``+#/```'
M1@``M,\```='``"XSP``!T@``+S/```'20``P,\```=*``#$SP``!TL``%.#
M[`CH>P8``('#U[P``(N#%`$``(7`=`7HW@,``(/$"%O#`/^S!````/^C"```
M``````#_HPP```!H`````.G@_____Z,0````:`@```#IT/____^C%````&@0
M````Z<#_____HQ@```!H&````.FP_____Z,<````:"````#IH/____^C(```
M`&@H````Z9#_____HR0```!H,````.F`_____Z,H````:#@```#I</____^C
M+````&A`````Z6#_____HS````!H2````.E0_____Z,T````:%````#I0/__
M__^C.````&A8````Z3#_____HSP```!H8````.D@_____Z-`````:&@```#I
M$/____^C1````&AP````Z0#_____HT@```!H>````.GP_O___Z-,````:(``
M``#IX/[___^C4````&B(````Z=#^____HU0```!HD````.G`_O___Z-8````
M:)@```#IL/[___^C7````&B@````Z:#^____HV````!HJ````.F0_O___Z-D
M````:+````#I@/[___^C:````&BX````Z7#^____HVP```!HP````.E@_O__
M_Z-P````:,@```#I4/[___^C=````&C0````Z4#^____HW@```!HV````.DP
M_O___Z-\````:.````#I(/[___^C@````&CH````Z1#^____HX0```!H\```
M`.D`_O___Z.(````:/@```#I\/W___^CC````&@``0``Z>#]____HY````!H
M"`$``.G0_?___Z.4````:!`!``#IP/W___^CF````&@8`0``Z;#]____HYP`
M``!H(`$``.F@_?___Z.@````:"@!``#ID/W___^CI````&@P`0``Z8#]____
MHZ@```!H.`$``.EP_?___Z.L````:$`!``#I8/W___^CL````&A(`0``Z5#]
M____H[0```!H4`$``.E`_?___Z.X````:%@!``#I,/W___^CO````&A@`0``
MZ2#]____H\````!H:`$``.D0_?___Z/$````:'`!``#I`/W___^CR````&AX
M`0``Z?#\____H\P```!H@`$``.G@_/___Z/0````:(@!``#IT/S___^CU```
M`&B0`0``Z<#\____H]@```!HF`$``.FP_/___Z/<````:*`!``#IH/S___^C
MX````&BH`0``Z9#\____H^0```!HL`$``.F`_/___Z/H````:+@!``#I</S_
M__^C[````&C``0``Z6#\____H_````!HR`$``.E0_/___Z/T````:-`!``#I
M0/S___^C^````&C8`0``Z3#\____HQ`!``!FD/^C%`$``&:0C4PD!(/D\/]Q
M_%6)Y5=64U&)SNAH`@``@</$N```@^PLBT$$B474BT$(B4709:$4````B47D
M,<"-1=!0C4744%'HNOW__XN#'`$``(/$#%!0_[,D`0``Z`1)``"+@PP!``"#
MQ!"`.``/A"8!``"+NP@!``"#[`S_-^@2____@(C^`@```EK_-^@#____@(C^
M`@```8L&@\00@\`%/?___S\/AUD!``"#[`S!X`)0Z-W\__^+?=2+-H/$$(F#
M>!$``,>#?!$```0```"+%X/^`8D0C9,SD___B5`$BY-``0``B5`(C9,VD___
MB5`,N@$```!^$HUT)@"+#)>)3)`,@\(!.=9U\H/L#,=$L`P`````@\8#:@!0
MC8-D=___5E#_LX01``#HMOW__X/$((7`B<8/A)8```"#[`S_LX01``"-?>#H
MR/O__XV#`Y+__XGZZ/LG``"#Q!"%P`^$A0```(/L#/^SA!$``.AB^___Z#W]
M__^#Q!")\(M]Y&4S/10````/A:D```"-9?!96UY?78UA_,/HM_O__X7`B8.$
M$0``#X2/````@^P,4.@0^___B[L(`0``6?\WZ-+]__^#Q!#&@'$%````Z:?^
M__^#[`S_LX01``#H9?W__X/$$(G&Z5+___^+@X`1``"%P'0E@^P,4.CH1@``
M@\00Z6#___]04(V#LY'___^S&`$``%#H//S__XV#N)'__XGZZ"\G``"%P(F#
M@!$```^$,?___^N^Z-I'``"#[`QJ`>B@^___,>U>B>&#Y/!05%+H(@```('#
MC+8``(V#))'__U"-@\20__]045;_LR`!``#HK_O___2+'"3#9I!FD&:09I!F
MD(L<),-FD&:09I!FD&:09I#H%P$``('"1[8``(V*1`$``(V"1P$``"G(@_@&
M=A>+@OP```"%P'0-58GE@^P44?_0@\00R?/#B?:-O"<`````Z-<```"!P@>V
M``!5C8I$`0``C8)$`0``B>53*<C!^`*#[`2)P\'K'P'8T?AT%(N2+`$``(72
M=`J#[`A04?_2@\00BUW\R<.)]HV\)P````!5B>53Z%?___^!P[.U``"#[`2`
MNU0!````=2>+@Q`!``"%P'01@^P,_[,X`0``Z)W\__^#Q!#H-?___\:#5`$`
M``&+7?S)PXGVC;PG`````.@W````@<)GM0``C8+<_O__BPB%R74)Z43___^-
M="8`BY(H`0``A=)T[56)Y8/L%%#_TH/$$,GI)/___XL4),-55XUH.%93@>P,
M`P``B40D3(U$)'B)="0098L=%````(F<)/P"```QVXE$)`B)?"04B<&0C70F
M`(M4G0"+1)T$QT39!`````#'1-D,`````,=$)`0`````#\J)!"2)%-F)PL'H
M&,'J"('B`/\```G0BQ0DB<>+!"3!XAC!X`@)UR4``/\`"?B)1-D(@\,"@_L0
M=:6+1"0(C90D>`(``(D4)(G%D(UT)@"+56B+16R#Q0@S53@S13PS50@S10PS
M5?@S1?S'17P`````B<>)T(G1#ZSX'P'1"<&)37@[+"1UR(M$)$R+<`R+2!R+
M6`B+.(MH!(M0&(ET)!R)3"0,BW`4BT@@B5PD&(M8$(EL)!2)5"0(,=*)3"18
MB70D!(GYB?Z)'"2+6"0/K.D;P>8%B7PD$(GUBW0D6(E<)%P)S0-T)'B+?"1<
M$WPD?(GHB?&!P9EY@EJ)^X/3``'(BTPD&!':BQPDB40D((E4)"2+5"0(B=\Q
MUR'/B?J+?"0(BW0D((M$)!C'1"0D`````,=$)#0`````,?H!UHM4)!R)QXET
M)"")="0HP><>B<:)^8M\)`@/K-8"B<V+!"2+5"0D"?4#O"2`````B6PD,(ML
M)`P3K"2$````B?F!P9EY@EJ)ZXML)#")3"0X@],`BTPD.(E<)#S'1"0\````
M`#'%BT0D$(GO(<>+1"0@B?N+/"2)QC'[B<>+1"00`=G!Y@6)="0XBW0D.(G+
M#ZS7&XM4)!2)P0G^`?/!X1XQ_P^LT`*)S8M4)#")7"10"<6);"0XBVPD(/?5
M(>J+;"0H(VPD.,=$)"P`````QT0D1`````")Z(G5BU0D)`G%BP0D`X0DB```
M`(GIQT0D)``````%F7F"6@'!B=C!X`6)1"0HB=B+;"0H#ZSX&XE$)$`+;"1`
MBT0D(`'IB4PD*(E,)&")P<'A'@^LT`*)S8M4)#@)Q8M$)#");"1`B=WWU2'J
MBVPD4"-L)$`)Z@.$))````")T8M4)"P%F7F"6@'!BT0D*,'@!8E$)""+1"0H
MBVPD(`^LT!N)VHE$)#`+;"0P`>F)_8G?#ZSO`L'B'HE,)%")3"0@B=4)_8EL
M)##'1"0T`````(ML)"B+5"1`BW0D.,=$)#P`````]]4AZHML)&`C;"0PB>B)
MU8M4)"0)Q0.T))@```")Z8GP!9EY@EH!P8M$)"")RXG&B<>+1"0HP>8%B70D
M.(MT)#@/K-<;BU0D+(G!QT0D+``````)_@'SP>$>,?\/K-`"B<V+5"0PB5PD
M8`G%BT0D0(EL)#B+;"0@]]4AZHML)%`C;"0X">H#A"2@````B=&+5"0D!9EY
M@EH!P8G8P>`%B40D*(G8BVPD*`^L^!N)1"1`"VPD0(M$)"`!Z8E,)%")3"0H
MB<'!X1X/K-`"B<V)V@G%]]*);"1`(U0D.(ML)&`C;"1`BT0D,(MT)#C'1"0D
M`````,=$)$0`````QT0D-``````)Z@.$)*@```")T8M4)"P%F7F"6@'!BT0D
M*,'@!8E$)""+1"0HBVPD(`^LT!N)VHE$)#`+;"0P`>F)_8G?#ZSO`L'B'HE,
M)"")3"1@B=6+5"1`"?V);"0PBVPD*/?5(>J+;"10(VPD,(GHB=6+5"0D"<4#
MM"2P````B>F)\`69>8):`<&+1"0@B<N)QHG'BT0D*,'F!8ET)#B+="0X#ZS7
M&XG!"?X!\\'A'C'_B5PD4(M4)"R)S<=$)"P`````QT0D/`````#'1"1$````
M``^LT`*+5"0P"<6+1"1`B6PD.(ML)"#WU2'JBVPD8"-L)#@)Z@.$)+@```")
MT8M4)"0%F7F"6@'!B=C!X`6)1"0HB=B+;"0H#ZSX&XE$)$`+;"1`BT0D(`'I
MB4PD*(E,)&")P<'A'@^LT`*)S8G:"<7WTB-4)#B);"1`BVPD4"-L)$"+1"0P
M">H#A"3`````B=&+5"0L!9EY@EH!P8M$)"C!X`6)1"0@BT0D*`^LT!N)VHE$
M)#"+;"0@"VPD,(MT)#C'1"0D`````,=$)#0`````QT0D/``````!Z8G]B=\/
MK.\"P>(>B4PD((E,)%")U8M4)$`)_8EL)#"+;"0H]]4AZHML)&`C;"0PB>B)
MU8M4)"0)Q0.T),@```")Z8GP!9EY@EH!P8M$)"")RXG&B<>+1"0HP>8%B70D
M.(MT)#@/K-<;BU0D+(G!"?X!\\'A'C'_#ZS0`HG-BU0D,(E<)&`)Q8M$)$")
M;"0XBVPD(/?5(>J+;"10(VPD.`GJ`X0DT````(G1!9EY@EH!P8G8P>`%B40D
M*(G8#ZSX&XE$)$"+;"0H"VPD0(M$)""+5"0DQT0D+`````#'1"1$`````,=$
M)"0`````QT0D-`````"+="0X`>F)3"0HB4PD4(G!P>$>#ZS0`HG-B=H)Q??2
M(U0D.(EL)$"+;"1@(VPD0(M$)#`)Z@.$)-@```")T8M4)"P%F7F"6@'!BT0D
M*,'@!8E$)""+1"0HBVPD(`^LT!N)VHE$)#`+;"0P`>F)_8G?#ZSO`L'B'HE,
M)&")3"0@B=6+5"1`"?V);"0PBVPD*/?5(>J+;"10(VPD,(GHB=4)Q0.T).``
M``"+5"0DB>G'1"0\`````,=$)$0`````B?`%F7F"6@'!BT0D((G+B<:)QXM$
M)"C!Y@6)="0XBW0D.`^LUQN+5"0LB<''1"0L``````G^`?/!X1XQ_P^LT`*)
MS8M4)#")7"10"<6+1"1`B6PD.(ML)"#WU2'JBVPD8"-L)#@)Z@.$).@```")
MT8M4)"0%F7F"6@'!B=C!X`6)1"0HB=B+;"0H#ZSX&XE$)$`+;"1`BT0D(`'I
MB4PD8(E,)"B)P<'A'@^LT`*)S8G:"<7WTB-4)#B);"1`BVPD4"-L)$"+1"0P
MBW0D.,=$)"0`````QT0D-`````#'1"0\``````GJ`X0D\````(G1BU0D+`69
M>8):`<&+1"0HP>`%B40D((M$)"B+;"0@#ZS0&XG:B40D,`ML)#`!Z8G]B=\/
MK.\"P>(>B4PD((E,)%")U8M4)$`)_8EL)#"+;"0H]]4AZHML)&`C;"0PB>B)
MU8M4)"0)Q0.T)/@```")Z8GP!9EY@EH!P8M$)"")RXG&B<>+1"0HP>8%B70D
M.(MT)#@/K-<;BU0D+(G!"?X!\\'A'C'_#ZS0`HG-B5PD8`G%B6PD.(ML)""+
M5"0PBT0D0,=$)"P`````]]4AZHML)%`C;"0X">H#A"0``0``B=&+5"0DQT0D
M)``````%F7F"6@'!B=C!X`6)1"0HB=B+;"0H#ZSX&XE$)$`+;"1`BT0D(`'I
MB4PD*(E,)%")P<'A'@^LT`*)S8G:"<7WTB-4)#B);"0@BVPD8"-L)""+1"0P
M">H#A"0(`0``B=&+5"0L!9EY@EH!P8M$)"C!X`6)1"0PBT0D*(ML)#`/K-`;
MB=J)1"1`"VPD0`'IB?V)WP^L[P+!XAZ)3"1@B4PD,,=$)#0`````BVPD*(G3
MBU0D(`G[BW0D.(E<)&B)7"1`]]7'1"1$`````,=$)"0`````(>J+;"10(=V)
MZ(G5BU0D-`G%`[0D$`$``(GIB?`%F7F"6@'!BT0D,(G+B<:)QXM$)"C!Y@6)
M="0XBW0D.`^LUQN+5"0LB<$)_@'SP>$>,?\/K-`"B<V+3"0@B=X)Q0.,)!@!
M``")7"10BUPD:(EL)#B+5"0TB<@%H>O9;C'KBVPD8#'=B>D!P8GPP>`%B40D
M((GPBVPD(`^L^!N)1"0H"VPD*(M$)#`!Z8E,)&")3"0@B<'!X1X/K-`"B<N+
M5"1`"<,#E"0@`0``BVPD4(E<)$#'1"0L`````(G0BU0D)`6AZ]EN,UPD.#'=
MB?.)Z0'!BT0D(,'@!8E$)"B+1"0@BVPD*`^LT!N)\HE$)#`+;"0P`>G!XAX/
MK/L"B=6+E"0H`0``B4PD*`G=B4PD4(M<)$"+3"0XB6PD.('"H>O9;HG0BU0D
M*`'(,>N+;"1@BTPD*#'=BUPD+(GN`<;!X@6+1"0@B50D,(ML)#`/K-D;BU0D
M)(GS"<V)P0'KP>$>,?\/K-`"B<V+C"0P`0``B5PD8`G%BT0D0(G>B6PD,(ML
M)#B!P:'KV6X!R#-L)#"+5"0L,VPD4,=$)"0`````QT0D+`````")Z0'!B=C!
MX`6)1"0@B=B+;"0@#ZSX&XE$)$`+;"1`BT0D*`'IB4PD((E,)%")P<'A'@^L
MT`*)RXN,)#@!``"+5"0D"<.+1"0XB=V)7"0XBUPD,('!H>O9;@'(,>N+;"1@
M,=V+G"1``0``B>D!P8M$)"#!X`6)1"0HBT0D((ML)"@/K-`;B?*)1"1`"VPD
M0(M$)#`!Z<'B'@^L_@*)U8E,)"B)3"1@"?6!PZ'KV6Z)[XML)#@!V(E\)$`Q
M_8GNBVPD4#'UB>D!P8M$)"B+5"0LB<:)QXM$)"#!Y@6)="0PBW0D,`^LUQN+
M5"0DQT0D)``````)_@'Q,?^)SHE,)%")P<'A'@^LT`*)S8N,)$@!``"+5"0L
M"<6+1"0XB6PD,(ML)$"!P:'KV6X!R#-L)#`S;"1@B>D!P8GPP>`%B40D((GP
MBVPD(`^L^!N)1"0X"VPD.(M$)"@!Z8E,)"")3"1@B<'!X1X/K-`"B<N+C"10
M`0``BU0D)`G#BT0D0(G=B5PD.(M<)#"!P:'KV6X!R#'KBVPD4#'=B>D!P8M$
M)"#!X`6)1"0HBT0D((ML)"@/K-`;B?*)1"1`"VPD0(N<)%@!``"+1"0PQT0D
M+``````!Z<'B'@^L_@*)U8E,)%")3"0H"?6!PZ'KV6Z+5"0LB>^+;"0X`=B)
M?"1`,?V)[HML)&`Q]8GI`<&+1"0HB<N)QHG'BT0D(,'F!8ET)#"+="0P#ZS7
M&XM4)"2)P<=$)"0`````"?X!\\'A'C'_#ZS0`HG-BXPD8`$``(M4)"P)Q8M$
M)#B)WHEL)#"+;"1`@<&AZ]ENB5PD8`'(,VPD,#-L)%")Z0'!B=C!X`6)1"0@
MB=B+;"0@#ZSX&XE$)#@+;"0XBT0D*`'IB4PD4(E,)"")P<'A'@^LT`*)RXN,
M)&@!```)PXM$)$"+5"0DB5PD.(G=BUPD,('!H>O9;L=$)"P``````<@QZXML
M)&`QW8N<)'`!``")Z0'!BT0D(,'@!8E$)"B+1"0@BVPD*`^LT!N)\HE$)$`+
M;"1`BT0D,`'IP>(>#ZS^`HG5B4PD8(E,)"@)]8'#H>O9;HM4)"R)[XML)#@!
MV(E\)$`Q_8GNBVPD4#'UB>D!P8M$)"B)RXG&B<>+1"0@P>8%B70D,(MT)#`/
MK-<;BU0D)(G!"?X!\\'A'C'_#ZS0`HG-BXPD>`$``(E<)%`)Q8M$)#B)WHEL
M)#"+;"1`@<&AZ]EN`<@S;"0P,VPD8(GI`<&)V,'@!8E$)"")V(ML)"`/K/@;
MBU0D+,=$)"0`````B40D.`ML)#B+1"0HQT0D+``````!Z8E,)"")3"1@B<'!
MX1X/K-`"B<N+E"2``0``"<.+1"1`B=V)7"0XBUPD,('"H>O9;@'0BU0D)#'K
MBVPD4#'=BYPDB`$``(GI`<&+1"0@P>`%B40D*(M$)""+;"0H#ZS0&XGRB40D
M0`ML)$"+1"0P`>G!XAX/K/X"B=6)3"0HB4PD4`GU@<.AZ]ENBU0D+(GOBVPD
M.`'8B7PD0#']B>Z+;"1@,?6)Z0'!BT0D*(G&B<?!Y@6)="0PBW0D,`^LUQL)
M_@'Q,?^)3"1@BT0D((G.BU0D),=$)"0`````B<'!X1X/K-`"B<V+C"20`0``
MBU0D+`G%BT0D.,=$)"P`````B6PD,(ML)$"!P:'KV6X!R#-L)#`S;"10B>D!
MP8GPP>`%B40D((GPBVPD(`^L^!N)1"0X"VPD.(M$)"@!Z8E,)"")3"10B<'!
MX1X/K-`"B<N+C"28`0``BU0D)`G#BT0D0(G=B5PD.(M<)#"!P:'KV6X!R#'K
MBVPD8#'=B>D!P8M$)"#!X`6)1"0HBT0D((ML)"@/K-`;B?*)1"1`"VPD0`'I
MP>(>#ZS^`HG5B4PD8(E,)"@)]8N<)*`!``"+1"0PB>^+;"0XBU0D+(E\)$#'
M1"0T`````('#H>O9;@'8,?V)[HML)%`Q]8GIBVPD8`'!BT0D*(G+B<:)QXM$
M)"#!Y@6)="0PBW0D,`^LUQN+5"0DB<''1"0D``````G^`?/!X1X/K-`"B<Z+
ME"2H`0``BTPD0`G&BT0D.(E<)#")]XE<)%"!PJ'KV6X!T#'QBU0D-#'-B>D!
MP8M$)##!X`6)1"0@BT0D,(ML)"`/K-`;BU0D+(E$)#@+;"0XBT0D*`'IB4PD
M8(E,)"")P<'A'@^LT`*)SHN4)+`!``")^0G&BT0D0(E\)&B+;"10BWPD(('"
MH>O9;HET)#B+7"0X`=`Q\8M4)#0QS<=$)"P`````QT0D-`````")Z8ML)"0!
MP8GXP>`%B40D*(GX#ZSH&XML)"@)Q8M$)#`!Z8E,)%")3"0HB<>)P8M$)&`/
MK-<"P>$>B=J)S0G]B=^+7"0L">\AZHEL)$`A^(M\)"2)P0G1BU0D*(G.BXPD
MN`$``('!W+P;CXG(BTPD:`'(BTPD*`'&P>(%BT0D4(E4)#"+;"0P#ZS9&XGS
MBW0D(`G-`>N)\8E<)#")7"1@#ZS^`L'A'HM<)$")SXM,)#@)]XGZB7PD4`G:
M(=")^B':B<4)U8N4),`!``")[H'"W+P;CXG0BU0D,`'(`<;!X@6)5"0@BTPD
M,(M<)#2+;"0@BWPD+(M$)&#'1"0D`````,=$)"P`````#ZS9&XGSBW0D*`G-
M`>N)\8E<)"")7"1H#ZS^`HM\)%#!X1Z)RXM,)$`)\XGZB5PD.`G:(=")^B':
MB<6+7"0D"=6+E"3(`0``B>Z!PMR\&X^)T(M4)"`!R(M,)"`!QHM$)&C!X@6)
M]XMT)#")5"0HBVPD*`^LV1N+7"0XBY0DT`$```G-B?$![\'A'HE\)"B)?"1@
MB<V+?"0TB=D/K/X""?4)Z2'KB6PD0"'(B<$)V8'"W+P;CXM<)"R)SHM,)%")
MT(M4)"@!R(M,)"@!QL'B!8E4)#"+;"0P#ZS9&XGSBW0D((M\)"0)S8M$)&#'
M1"0T``````'KQT0D)`````")\8E<)&B)7"0P#ZS^`L'A'HM<)$")SXM,)#@)
M]XGZB7PD4`G:(=")^HM\)"PAVHG%BUPD-`G5BY0DV`$``(GN@<+<O!N/B="+
M5"0P`<B+3"0P`<:+1"1HP>(%B50D((ML)"`/K-D;B?.+="0H"<T!ZXGQB5PD
M((E<)&`/K/X"BWPD4,'A'HG+BTPD0`GSB?J)7"0X"=HAT(GZ(=J)Q8M<)"0)
MU8N4).`!``")[H'"W+P;CXG0BU0D(`'(BTPD(`'&P>(%B?>)5"0HBVPD*`^L
MV1L)S0'OB7PD:(E\)"B+="0PBWPD-(M<)#B+1"1@BY0DZ`$``,=$)"P`````
MB?''1"0T``````^L_@+!X1Z+?"0DQT0D)`````")S8G9"?4)Z2'KB6PD0"'(
MB<$)V8'"W+P;CXM<)"R)SHM,)%")T(M4)"@!R(M,)"@!QL'B!8M$)&B)5"0P
MBVPD,`^LV1N)\XMT)"`)S0'KB?&)7"0PB5PD8`^L_@+!X1Z+7"1`B<^+3"0X
M"?>)^HE\)%`)VB'0B?HAVHG%BUPD-`G5BY0D\`$``(GN@<+<O!N/B="+5"0P
M`<B+3"0P`<;!X@6)5"0@BVPD(`^LV1N)\XMT)"@)S0'KB5PD:(E<)"")\8M\
M)"S!X1Z+1"1@B<N+3"1`QT0D+``````/K/X"BWPD4`GSB5PD.(GZ"=HAT(GZ
M(=J)Q8M<)"0)U8N4)/@!``")[H'"W+P;CXG0BU0D(`'(BTPD(`'&BT0D:,'B
M!8GWBW0D,(E4)"B+;"0H#ZS9&XM<)#B+E"0``@``"<V)\0'OP>$>B7PD*(E\
M)&")S8M\)#2)V<=$)#0`````#ZS^`HM\)"0)]0GI(>N);"1`(<B)P0G9@<+<
MO!N/BUPD+(G.BTPD4(G0BU0D*`'(BTPD*`'&P>(%B50D,(ML)#`/K-D;B?.+
M="0@"<T!ZXGQB5PD:(E<)#`/K/X"P>$>BUPD0(M$)&")SXM,)#C'1"0D````
M``GWB?J)?"10"=HAT(GZBWPD+"':B<6+7"0T"=6+E"0(`@``QT0D+`````")
M[H'"W+P;CXG0BU0D,`'(BTPD,`'&BT0D:,'B!8E4)""+;"0@#ZS9&XGSBW0D
M*`G-`>N)\8E<)"")7"1@#ZS^`HM\)%#!X1Z)RXM,)$`)\XGZB5PD.`G:(=")
M^B':B<6+7"0D"=6+E"00`@``B>Z!PMR\&X^)T(M4)"`!R(M,)"`!QHM$)&#!
MX@6)]XMT)#")5"0HBVPD*`^LV1N+7"0X"<V)\0'OP>$>B7PD:(E\)"B)S8M\
M)#2)V0^L_@()]0GI(>N);"1`(<B+E"08`@``BWPD)(G!QT0D-`````#'1"0D
M``````G9BUPD+(G.BTPD4('"W+P;CXG0BU0D*`'(BTPD*`'&P>(%BT0D:(E4
M)#"+;"0P#ZS9&XGSBW0D(`G-`>N)\8E<)#")7"1@#ZS^`L'A'HM<)$")SXM,
M)#@)]XGZB7PD4`G:(=")^HM\)"PAVHG%BUPD-`G5BY0D(`(``(GN@<+<O!N/
MB="+5"0P`<B+3"0P`<:+1"1@P>(%B50D((ML)"`/K-D;B?.+="0H"<T!ZXGQ
MB5PD:(E<)"`/K/X"BWPD4,'A'HG+BTPD0`GSB?J)7"0X"=HAT(GZ(=J)Q0G5
MBY0D*`(``(GN@<+<O!N/B="+5"0@BUPD)`'(BTPD(,=$)"P``````<:+1"1H
MP>(%B?>+="0PB50D*(ML)"@/K-D;BUPD.(N4)#`"```)S8GQ`>_!X1Z)?"0H
MB7PD8(G-BWPD-(G9QT0D-``````/K/X"BWPD)`GU">DAZXEL)$`AR(G!"=F!
MPMR\&X^+7"0LB<Z+3"10B="+5"0H`<B+3"0H`<;!X@6+1"1@B50D,(ML)#`/
MK-D;B?.+="0@"<T!ZXGQB5PD,(E<)&@/K/X"P>$>BUPD0(G/BTPD.`GWB?J)
M?"10"=HAT(GZ(=J)Q0G5BY0D.`(``(GN@<+<O!N/B="+5"0P`<@!QL'B!8E4
M)""+3"0PBUPD-(ML)""+?"0LBT0D:,=$)"0`````QT0D+``````/K-D;B?.+
M="0H"<T!ZXGQB5PD((E<)&`/K/X"BWPD4,'A'HG+BTPD0`GSB?J)7"0X"=HA
MT(GZ(=J)Q8M<)"0)U8N4)$`"``")[H'"W+P;CXG0BU0D(`'(BTPD(`'&BT0D
M8,'B!8GWBW0D,(E4)"B+;"0H#ZS9&XM<)#B+E"1(`@``"<V)\0'OP>$>B7PD
M*(E\)&B)S8M\)#2)V0^L_@()]0GI(>N);"1`(<B)P0G9@<+<O!N/BUPD+(G.
MBTPD4(G0BU0D*`'(BTPD*`'&P>(%B50D,(ML)#`/K-D;B?.+="0@BWPD)`G-
MBT0D:,=$)#0``````>O'1"0D`````(GQB5PD,(E<)&`/K/X"P>$>BUPD0(G/
MBXPD5`(```GWB?J)?"10"=HAT(GZ,?\AVHG%"=6+E"10`@``B>Z!PMR\&X^#
MT0")T#';B<J+3"0X`<B+3"0P$=H!QHM<)#01UXM4)#`/K-D;P>(%B?.)_HE4
M)""+;"0@,=*+?"0L"<T!ZXML)%`1UHN4)%@"``")7"0@B70D;(MT)"B)7"1H
MBUPD)(GQ#ZS^`L'A'HGPB<Z+3"1`"<:!PM;!8LJ)T(M4)"")="0X`<@Q]8GI
MBVPD8#'-BTPD((GN`<;!X@6)5"0HBVPD*`^LV1N+?"0PB?.+E"1@`@``"<W'
M1"0L``````'KBVPD-,=$)#0`````B?F)7"1@B5PD*,'A'HM<)&@/K.\"B<V+
M3"10"?V!PM;!8LJ+?"0DB="+5"0HB6PD0`'(BTPD.#'I,<N+3"0HB=Z+7"0L
M`<;!X@6+1"0XB50D,(ML)#`/K-D;B?.+="0@BU0D-`G-`>N+;"1@B?&)7"0P
MB5PD4,'A'HM<)$`/K/X"B<^+C"1H`@``"?>)?"0X@<'6P6+*`<@Q^S'=B>D!
MP8M$)#")RXG&#ZS0&\'F!8E$)""+;"0@"?4!ZXE<)&")7"0@QT0D)`````"+
M="0HBWPD+(ML)#B+1"1`BU0D)(GQQT0D+``````/K/X"P>$>"?&)SHN,)'`"
M``")="1`@<'6P6+*`<@Q]8GNBVPD4#'UB>D!P8M$)"")Q\'G!8E\)"B)QXMT
M)"@/K-<;BT0D,(M4)#0)_@'Q,?^)SHE,)%")P<'A'@^LT`*)S8N4)'@"```)
MQ8M$)#B);"0PBVPD0('"UL%BR@'0,VPD,(M4)"0S;"1@B>D!P8GPP>`%B40D
M*(GPBVPD*`^L^!N)1"0X"VPD.(M$)"`!Z8E,)&")3"0HB<'!X1X/K-`"B<N+
MC"2``@``"<.+1"1`B=V)7"0XBUPD,('!UL%BRHM4)"S'1"0D``````'(,>N+
M;"10,=V+G"2(`@``B>D!P8M$)"C!X`6)1"0@BT0D*(ML)"`/K-`;B?*)1"1`
M"VPD0(M$)#`!Z<'B'@^L_@*)U8E,)%")3"0@"?6!P];!8LJ+5"0DB>^+;"0X
M`=B)?"1`,?V)[HML)&`Q]8GI`<&+1"0@B<N)QHG'BT0D*,'F!8ET)#"+="0P
M#ZS7&XM4)"R)P0G^`?/!X1XQ_P^LT`*)S8N,))`"``")7"1@"<6+1"0XB=Z)
M;"0PBVPD0('!UL%BR@'(,VPD,#-L)%")Z0'!B=C!X`6)1"0HB=@/K/@;B40D
M.(ML)"@+;"0XBT0D((M4)"3'1"0L`````,=$)"0``````>F)3"10B4PD*(G!
MP>$>#ZS0`HG+BXPDF`(``(M4)"P)PXM$)$")W8E<)#B+7"0P@<'6P6+*`<@Q
MZXML)&`QW8N<)*`"``")Z0'!BT0D*,'@!8E$)""+1"0HBVPD(`^LT!N)\HE$
M)$`+;"1`BT0D,`'IP>(>#ZS^`HG5B4PD((E,)&`)]8'#UL%BRHM4)"2)[XML
M)#@!V(E\)$`Q_8GNBVPD4#'UB>D!P8M$)"")RXG&B<?!Y@6)="0PBW0D,`^L
MUQL)_@'S,?^)7"10BT0D*(G>BU0D+,=$)"P`````B<'!X1X/K-`"B<V+C"2H
M`@``BU0D)`G%BT0D.,=$)"0`````B6PD,(ML)$"!P=;!8LH!R#-L)#`S;"1@
MB>D!P8G8P>`%B40D*(G8BVPD*`^L^!N)1"0X"VPD.(M$)"`!Z8E,)"B)3"1@
MB<'!X1X/K-`"B<N+E"2P`@``"<.+1"1`B=V)7"0XBUPD,('"UL%BR@'0BU0D
M+#'KBVPD4#'=B>D!P8M$)"C!X`6)1"0@BT0D*(ML)"`/K-`;B?*)1"1`"VPD
M0`'IP>(>#ZS^`HG5B4PD4(E,)"`)]8N<)+@"``"+1"0PB>^+;"0XBU0D)(E\
M)$"!P];!8LH!V#']B>Z+;"1@,?6)Z0'!BT0D((G+B<:)QXM$)"C!Y@6)="0P
MBW0D,`^LUQN+5"0LB<''1"0L``````G^`?/!X1XQ_P^LT`*)S8N,),`"``"+
M5"0D"<6+1"0XB5PD8(EL)#"+;"1`B=Z!P=;!8LH!R#-L)#`S;"10B>D!P8G8
MP>`%B40D*(G8BVPD*`^L^!N)1"0X"VPD.(M$)"`!Z8E,)%")3"0HB<'!X1X/
MK-`"B<N+E"3(`@``"<.+1"1`B=V)7"0XBUPD,('"UL%BR@'0,>N+;"1@,=V)
MZ0'!BT0D*(M4)"R+G"30`@``QT0D)`````#!X`6)1"0@BT0D*(ML)"`/K-`;
MB?*)1"1`"VPD0(M$)#`!Z<'B'@^L_@*)U8E,)&"+5"0D"?6!P];!8LJ)3"0@
MB>^+;"0X`=B)?"1`,?V)UXGNBVPD4#'UB>D!P8M$)"")RP^DQP6)QL'F!8E\
M)#2)QXET)#"+1"0HBW0D,`^LUQN+5"0LB<$)_@'SP>$>,?\/K-`"B<V+C"38
M`@``B=X)Q8E<)%"+1"0XBYPDW`(``(EL)#"!P=;!8LJ+;"1`@],`,=(!R!':
M,VPD,#';,VPD8(GI`<&)\!'3P>`%,=*)1"0HB?`/K/@;B40D.(ML)"@+;"0X
MBT0D(,=$)"P``````>D1TXM4)"2)3"0HB4PD8(G!B5PD9,'A'L=$)"0`````
M#ZS0`HG+BY0DX`(```G#BT0D0(G=B5PD.(M<)#"!PM;!8LH!T(M4)"PQZXML
M)%`QW8N<).@"``")Z0'!BT0D*,'@!8E$)""+1"0HBVPD(`^LT!N)\HE$)$`+
M;"1`BT0D,`'IP>(>#ZS^`HG5B4PD((M4)"0)]8'#UL%BRHE,)$")[XML)#@!
MV(E\)#`Q_8G7B>Z+;"1@,?6)Z0'!BT0D(`^DQP6)QL'F!8E\)%2)QXET)%"+
M="10#ZS7&XM4)"P)_HGP`<@Q_XG&BT0D*(G!P>$>#ZS0`HG-BU0D)`G%BT0D
M((EL)%")TXG!#Z3+'L'A'HE,)"")T8G"#ZS*`L'I`HM$)#B)7"0DB4PD+(N,
M)/`"``"+7"0PB50D*(GZ@<'6P6+*`<@QZXML)$`QW8GI`<&)\,'@!8E$)#B)
M\(ML)#@/K/@;#Z3R!8E$)$`+;"1`B50D/(GZP>H;B50D1(M4)$R)Z(ML)"`!
MR(G!BT0D&`-,)!#'0@0`````QT(,``````'P"VPD*(E""(D*B>@#!"2)0A"+
M1"10`T0D",="%`````#'0AP`````QT(D`````(E"&(M$)#`#1"18B4(@BX0D
M_`(``&4S!10```!U"X'$#`,``%M>7UW#Z,@@``"0C;0F`````%575E/H)]G_
M_X'#@X\``(/L'(7`#X2K````BXLP`0``BPF%R8E,)`@/A)<````/M@B$R71K
M@/D]=&:)QH/&`0^V#H3)=`6`^3UU\2G&BTPD"(LIA>UT-HE4)`R)1"0$B<^-
MM"8`````@^P$5O]T)`Q5Z*K5__^#Q!"%P'4'@'PU`#UT)(/'!(LOA>UUVX/$
M'(GH6UY?7<.)]HV\)P`````Q]NNIC70F`(GZ*U0D"(M$)`R-;#4!P?H"B1"#
MQ!R)Z%M>7UW#,>WKQ(VT)@````!75HG&4^B"V?__@<*RC@``@^P0B[HP`0``
MC5PD"&6A%````(E$)`PQP(G:B?#H_O[__X7`=#N-=@"-O"<`````BU0D"(L'
MC020BU`$A=*)$'37C;8`````@\`$BU`$A=*)$'7TB=J)\.C#_O__A<!USXM$
M)`QE,P44````=0>#Q!!;7E_#Z&8?``"-M@````!55XG%5E.)UNC#U___@<,?
MC@``@^PX9:$4````B40D*#'`,<"`.CT/E,`!QE;H+M/__X/$$(D$)(GHC50D
M&.A=_O__A<`/A`T!``"#[`R)QU#H"M/__X/$$#D$)`^&W@```(M$)!B-#(4`
M````BX,P`0``B40D!`^V10"$P`^$G`$``#P]#X24`0``B>CK!I"`^CUT"H/`
M`0^V$(32=?$IZ(M4)`2#[`R+.@'/BTPD#(U$"`)0Z$;2__^#Q!"%P(D'#X1K
M`0``BU0D!(U-`8L"BU0D&(L4D`^V10`\/8@"=".$P'4/ZQV)]HV\)P`````\
M/700@\$!#[9!_X/"`83`B`)U[,8"/3'`C;0F``````^V#`:(3`(!@\`!A,EU
M\3'`BUPD'&4S'10````/A0H!``"#Q"Q;7E]=PXVV`````(/&`0^V1O^#QP&$
MP(A'_W7OZ\R0C70F`(N#,`$``(L0B40D!(LZA?\/A+@````QP.L(C;8`````
MB?B->`&+#+J%R77TC02%#````(N+=!$``(7)=#N#[`A04NA1T?__BTPD%(/$
M$(7`B0$/A((```"-#+T`````B40D"(M$)`C'1+@$`````(E\)!CII_[__XE4
M)`B#[`S'@W01```!````4.@9T?__@\00A<!T1(T,O0````"#[`11BU0D$(E,
M)!12B40D%%#HM,___XM,)!2+1"08@\00B0&+3"0,ZYPQP.E[_O__N`@````Q
M_^E9____N/_____IY?[__^@?'0``ZPV0D)"0D)"0D)"0D)"055=64XG&Z'75
M__^!P]&+``"![(P```!EH10```")1"1\,<"%]G0%@#X`=22+1"1\93,%%```
M``^%1`$``('$C````%M>7UW#D(VT)@````"#[`Q6Z'?2__^#Q!"%P(G'=,J-
M@V21__^)1"0(C40D'(E$)`R-="8`@^P,5^C/T?__@\00A<")Q0^$R@````^V
M51.X+@```(G!*=%U&P^V512%TG33*=`/A)L```#WV(7`=,7K!XUV`(7)=+R#
M[`Q6Z$O0__^-51.)1"04B10DB50D$.@XT/__BTPD%(U$`0*)!"3HR,___XG%
M6%J+5"0(4E;_="08:O]J`57HX-'__X/$'/]T)!!5:@/H<='__X/$$(/X_W00
MBT0D+"4`\```/0!```!T48/L#%7HT,[__X/$$(/L#%7H1,[__X/$$.DT____
MC70F``^V117I7O___XVT)@````"#[`Q7Z%_1__^)-"3H1\[__X/$$.F[_O__
MC;0F`````(GHZ('^___KLNB*&P``C78`C;PG`````%=6B<=3Z.;3__^!PT**
M``"#[`R+LP@!``#_-NC@T/__@\0,!3P!``!05VH#Z-_0__^#Q!"%P'0(6S'`
M7E_#9I"#[`S_-NBVT/__BX!,`0``@\00)0#P```]`$```'0?@^P,_S;HE]#_
M_XN`3`$``(/$$"4`\```/0"@``!UNH/L"&H"5^CGS___@\00A<`/E,!;#[;`
M7E_#D(VT)@````!55XG'5E/H1=/__X'#H8D``('L,!```&6A%````(F$)"`0
M```QP(E4)!!H_P\``(V#:I'__XUT)"164.BPS?__@\00A<!^88UH_X!\+!P`
M=$^)Q8/L!%5J+U;H$<___X/$$(7`=$*+@P@!``"#[`S_,.CJS___55974.B!
MS___@\0@BX0D'!```&4S!10```!U.8'$+!```%M>7UW#C78`A>UUKXUT)@"+
M@P@!``"#[`S_,.BHS___@\0,_W0D$%=0Z#K-__^#Q!#KM^@0&@``4^AZTO__
M@</6B```@^P4BX,(`0``_S#H=,___XV38)/__U*-DWF1____LP0!``!24.@J
MSO__@\0H6\.0C70F`%93Z#G2__^!PY6(``"#[!"+LP@!``#_-N@SS___B00D
MZ)O___]8_S;H(\___UJ-DQ"3__]9:@!24HV3A(S__U*-DY61__]24.ACSO__
M@\0D6U[#C;8`````C;PG`````%575E/HU]'__X'#,X@``('L'"```&6A%```
M`(F$)`P@```QP.BWS/__C9-UD?__@^P(4E"-@ZJ1__]0:`$0``!J`8UT)"96
MZ/3.__^#Q""%P'AM@^P$:``0``"-O"03$```5U;H%\S__X/$$(7`B<5X3HU`
M`8/L#%#HDLS__X/$$(7`B<9T$H/L!%574.A>R___Q@0N`(/$$(N,)`P@``!E
M,PT4````B?!U&8'$'"```%M>7UW#C78`C;PG`````#'VZ]7HIQ@``(VT)@``
M``#I*____XUT)@"-O"<`````55=64^CWT/__@<-3AP``@>PL$```BX0D0!``
M`(U4)!B+M"1$$```B00DB<=EH10```")A"0<$```,<"-@[B1___HBO?__X/L
M"(G%:B]7Z!W,__^#Q!"%P'0QBSPDC8/!D?__B?KHQOC__XGXBY0D'!```&4S
M%10````/A9@!``"!Q"P0``!;7E]=PX/L#/]T)`SH^<O__UI9B<>-@\Z1__^)
M1"0,4%;HY,S__XG&C4<!@\00B40D"(N#"`$``(E$)`R-M@````"%]G2.@#X`
M#X3;````A>UT%8/L"%95Z-W)__^#Q!"%P`^$HP```(/L#%;HF<O__X/$$(!\
M!O\O=16-M"8`````@^@!@'P&_R_&!`8`=/(#1"0(/?\/```/CS7___^-@]"1
M__^#[`3_="0$4(V#RY+__U90:``0``!J`8UT)#A6Z!3-__^#Q!2+?"08_S?H
MMLS__X/$#`4\`0``4%9J`^B5S/__@\00A<!U'X/L#/\WZ)3,__^+@$P!``"#
MQ!`E`/```#T`@```=%>#[`C_="0,:@#H\<O__X/$$(G&Z1____^-M"8`````
MA>UT)(V#MI'__[D"````B>Z)Q_.F=,J)QK@!````Z4/___^0C70F`(VSMI'_
M_[@!````Z2[___^#[`AJ`5;HC<O__X/$$(7`=9>-@\&1__^)\N@I]___@^P,
M5NCPRO__@\00Z53^___H<Q8``(UV`(M$)`0/M@B$R705C5`!9I"`^2\/M@H/
M1,*#P@&$R77P\\.-M"8`````C;PG`````%93Z*G.__^!PP6%``"#[!2+="0@
MA?9T4`^V%H32=$F(5"0/@^P,5N@4RO__C40&_X/$$`^V5"0/.<9R"^L>9I"#
MZ`$YQG09@#@O=/3K!V:0@#@O=$"#Z`$YQG+T.<9U-8#Z+W5SC78`@^P,:@+H
M;LG__X/$$(7`=%>Z+@```&:)$(/$%%M>PXGVC;PG`````(`X+W4'@^@!.<9R
M]"GPC5`"@?H`$```=R>#P`%H`!```%!6C;-T`0``5NA!RO__@\00B?"#Q!1;
M7L.-M@````"#Q!0QP%M>PXV#T)'__X/L#%#HR<G__X/$$.N5C70F`%=64^BX
MS?__@<,4A```@^PP9:$4````B40D+#'`BX,\D___C70D!(E$)`J+@T"3__^)
M1"0.BX-$D___B40D$HN#2)/__XE$)!:+@TR3__^)1"0:BX-0D___B40D'HN#
M5)/__XE$)"*+@UB3__^)1"0F#[>#7)/__V:)1"0JC8/2D?__Z-CT__^-@]N1
M___HS?3__XV#XY'__^C"]/__C8/LD?__Z+?T__^-@_.1___HK/3__XV#`Y+_
M_^BA]/__C8.XD?__Z);T__^-@P^2___HB_3__XV#&9+__^B`]/__C8,CDO__
MZ'7T__^-@\&1___H:O3__XV#+9+__XGRZ(WS__^%P'0-B<*-@QF2___HW/3_
M_XV#/I+__XGRZ&_S__^%P'0-B<*-@U"2___HOO3__XV#6Y+__XGRZ%'S__^%
MP'0UB<*-@[B1___HH/3__XV3AY+__XV#\Y'__^B/]/__BT0D+&4S!10```!U
M5H/$,%M>7\.-=@"-@VN2__^)\N@+\___A<!T%XG"C8,/DO__Z%KT___KN)"-
MM"8`````C70D&XV[?)+__[D*````\Z9UG8U4)"6-@P^2___H+O3__^N,Z(<3
M``"-M"8`````4^CJR___@<-&@@``@^P89:$4````B40D##'`BX,\`0``@_C_
M=!J+3"0,93,-%````'5!@\086\.0C;0F`````(U4)`B-@P^2___H<?+__X7`
M=!T/MA"`^C`/E<"$T@^5PB'0#[;`B8,\`0``Z[AFD#'`Z^_H!Q,``(VT)@``
M``!3Z&K+__^!P\:!``"#[`CHS,7__X/L#%#H,\7__X/$$(7`=`R+`(/$"%O#
MD(UT)@`QP.ORC;8`````C;\`````55=64^@GR___@<.#@0``@^P<9:$4````
MB40D##'`C50D"(V#B9+__XM\)##HS_'__X7`=#.`.`")QG0L@^P(5U#HFL3_
M_X/$$(7`=#.+1"0,93,%%````'5Y@\0<6UY?7<.-M@````"-@XF2__^)^NCK
M\O__Z]:)]HV\)P````"#[`Q7Z#?&__^)Q8DT).@MQO__C40%`HD$).C!Q?__
MB<6-@\Z1__^#Q`Q64(V#RY+__U=0:O]J`57HTL?__XV#B9+__X/$((GJZ)+R
M___I>O___^CH$0``D(VT)@````!55U93Z"(1``"!Q:.```"![#R!``"+A"10
M@0``C50D/(V=F9+__\=$)$@`````QT0D;`````")7"1,QT0D5`````")1"0<
MB50D%&6A%````(F$)"R!```QP(V%I9+__XE$)$"-A;:1__^)1"1$C850DO__
MB40D#(E$)%B-A4F2__^)1"1<C86JDO__B40D8(V%9I+__XE$)&2-A;*2__^)
M1"1HC86VDO__B40D4(V%N)'__^AH\/__A<!T"8`X``^%>P0``.@6_O__A<")
MQ@^$DP0``(/L#(GK5N@!Q?__C40``8D$).B5Q/__B40D((/$$(`^`'0VC86_
MDO__BWPD$(D$)(UT)@`/M@:#[`R)ZX/&`5#_="00:O]J`5>#QP+HB\;__X/$
M((`^`'7;C5PD6(M$)`R+?"04ZPZ0C70F`(/#!(L#A<!T+XGZZ-#O__^%P(G&
M=.J`.`!TY>@`]?__A<!TW(/L#(GK5NCAQ/__@\00A<")QW5"BUPD0#'VZPN#
MQ@&+7+1`A=MT+8`[`'0HB=CHR?3__X7`=.6#[`Q3B>OHJL3__X/$$(7`=-.)
MQ^L)C;0F`````#'_@^P,B>M7Z!O$__^#Q!"+3"00BQF#P02-D__^_O[WTR':
M@>*`@("`=.F)T\'K$/?"@(````]$TXU9`@]$RXG3`-.)ZX/9`RM,)!"#[`R-
MM`$$!```5NALP___B40D'(G!C87$DO___W0D(%"-A="1__^)1"0H4(V%R9+_
M_U>)SU!J_VH!4>ALQ?__@\0H:,`!``!7Z.[#__^#Q!"#^/\/A)(```"+O0@!
M``"#[`R)Z_\WZ/#$__^#Q`P%/`$``%#_="04:@/H[,3__XE$)#"#Q!"%P`^$
MI0```(/L#(GK_W0D&(M$)"S_,(V%J)/__U"+A0`!``!J`?\PZ'C$__^#Q"#'
M1"08`````(N,)"R!``!E,PT4````BT0D&`^%20H``('$/($``%M>7UW#C78`
MC;PG`````.AKP___BP"#^!$/A%[___^#[`A0_W0D&(M$)"S_,(V%;)/__U"+
MA0`!``!J`?\PZ`S$__^#Q"#'1"08`````.N2C;0F`````(/L#/\WZ![$__^+
M@$P!``"#Q!`E`/```#T`0```#X4X____@^P,_S?H^\/__XN`5`$``(E$)!#H
M3,'__X/$$#D$)`^%$____X/L#/\WZ-;#__^+@$P!``"#Q!`E_P$``#W``0``
M#X7P_O__@^P,B>M6Z-+!__^+5"0DB40D*(V%E)+__^A?[?__@\00A<`/A`0"
M``"#[`R)ZU#H><+__UI94(M$)"C_,.AK]?__B40D$(/$$(7`#X3<`0``@^P,
MB>N+?"0,5^C=P?__@\00@_@#?BV-=`?\B?N-O=*2__^Y!0```/.F=1B#^`0/
MA*8'``"`?`/[+P^$FP<``(UT)@#H(_K__X7`=1^#[`B)ZVH`_W0D#.BOP?__
MB40D+(/$$(7`#X5^`0``C96'DO__C;40D___C84/DO__B>N-O?F2___H`>[_
M_^C,P/__5E"-A>N2____="08_W0D&%!J_VH!_W0D-.@.P___@\0@B30DB7PD
M%(MT)""+?"08ZT"-=@"-O"<`````Z)O!__^#.!%U1(GK@\8!Z'S`__^#[`S_
M="0,5E#_="0H_W0D*/]T)#1J_VH!5^B]PO__@\0P@^P(B>MHP`$``%?H.L'_
M_X/$$(/X_W2R@^P,B>O_="08Z#2___^+?"0HC86XD?__B?KH4^W__XD\).CK
M^?__@\00Z8;]__^-=@"#[`R)ZU")1"00Z-'Y__^+1"00B00DZ/7`__^)1"0H
M@\00Z5S]__^_`0```(G8BW0D%.L/C70F`(M$O$R#QP&%P'0IB?+HENO__X7`
M=.J`.`!TY8/L#(GK4.BRP/__@\00A<!TTXG&Z2C[__^#[`R)ZXVUGI+__VH-
MZ,*___^)1"0@@\00Z2W[__^-M@````"+1"0<BP")!"3I%O[__VH":O]J[HM\
M)"A7Z%*___^#Q`QJ!HV$)#0!``")1"0<4%?H&[[__X/$$("\)"P!````=0Z`
MO"0M`0``0P^$;P8``&H`:@")ZVH`_W0D*.@/O___QX0D@`````$C16?'A"2$
M`````````,>$)(@```")J\WOQX0DC`````````#'A"20````_MRZF,>$))0`
M````````QX0DF````'94,A#'A"2<`````````,>$)*````#PX=+#QX0DI```
M``````#'A"2H`````````,>$)*P`````````QX0DL`````````#'A"2T````
M`````,>$)/@`````````@\00C40D<(DL)(E$)"R-A"2H````B40D()"#[`1H
M`(```/]T)!S_="0HBUPD$.@7O?__@\00A<")Q@^."P(``(N,))@```"+G"2<
M````B?")]<'@`XGWP?T?`<B#^P`/A\T!```YP0^'Q0$``(N,)*````"+G"2D
M````B80DF````(GXB>H/K.@=P>H=QX0DG``````````!R(F$)*````"+A"3H
M````$=J)E"2D````A<`/A&D!``"_0````"G'.?X/3OX#1"0@@^P$5_]T)!Q0
MBUPD$.BOO/__BX0D^`````'XB80D^````(/$$(/X0`^%(____XM$)"PI_@-\
M)!3HI,/__XUT)@"#_C\/CN@```"-1L"+;"0LB?Z)1"0HP>@&C5@!B40D),'C
M!@'[C78`BP:#QD")A"2H````BT;$B80DK````(M&R(F$)+````"+1LR)A"2T
M````BT;0B80DN````(M&U(F$)+P```"+1MB)A"3`````BT;<B80DQ````(M&
MX(F$),@```"+1N2)A"3,````BT;HB80DT````(M&[(F$)-0```"+1O")A"38
M````BT;TB80DW````(M&^(F$).````"+1OR)A"3D````B>CHS\+__SGS#X5/
M____BTPD*(G(@^#`C7P'0(M$)"3!X`8IP8G.:D165_]T)"R+7"00Z+Z\__^)
MM"3X````@\00Z?_]__^-M"8`````BWPD%.G?_O__C;0F`````(N,)*````"+
MG"2D````@\$!@],`Z3#^__^++"2#[`S_="0HB>OH3K[__XN$)+````"+G"2H
M````B[0DK````(N4)+0```")1"00B=@/K/`#B50D%(/@/XU0`<:$!+@```"`
M@\00@_HX#X^D`@``N#@````IT`-4)""#^`0/@\D"``"%P'0+J`+&`@`/A7\#
M``"+5"0$BP0DB)PDYP````^LT!B+5"0$B(0DX````(L$)`^LT!"+5"0$B(0D
MX0```(L$)`^LT`B(A"3B````#[8$)(B$).,```")V`^L\!B(A"3D````B=@/
MK/`0B(0DY0```(G8#ZSP"(B$).8```"+1"0LZ&_!__^+="1PBWPD=(GQ#ZSY
M&(B,).\````/ML&)\0^L^1"(C"3P````B?$/K/D(BWPD?(B,)/$```")\8MT
M)'B(C"3R````B?$/K/D8B(PD\P```(GQ#ZSY$(B,)/0```")\0^L^0B+O"2$
M````B(PD]0```(GQB[0D@````(B,)/8```")\0^L^1B(C"3W````B?$/K/D0
MB(PD^````(GQ#ZSY"(N\)(P```"(C"3Y````B?&+M"2(````B(PD^@```(GQ
M#ZSY&(B,)/L```")\0^L^1"(C"3\````B?$/K/D(B[PDE````(B,)/T```")
M\8NT))````"(C"3^````B?$/K/D8B(PD_P```(GQ#ZSY$(B,)``!``")\0^L
M^0B-O"0K`0``B(PD`0$``(GQC;0D\````(B,)`(!``"-C"0#`0``B4PD'(G*
MC8V_DO__B0PDB7PD%(GWB=;I!P```)`/M@>#QP&#[`R)ZU#_="00:O]J`5:#
MQ@+H([S__X/$(#ET)!1UVHV%$)/__\:$)"L!````B>M0C87<DO___W0D(/]T
M)!C_="084&K_:@'_="0TZ.F[__^#Q"#I/_G__XM$)!R+4`2%T@^$6OC__X/L
M#(GK4HE4)"3H\[G__X/$$(/X`P^&/_C__XM4)!2-O=>2__^Y!0```(UT`OSS
MI@]%%"2)%"3I'OC__XM,)""X0`````'1*=")PG0-,<#&!`$`@\`!.=!R]8M$
M)"SH/[___XM\)""Y#@```#'`\ZOI1OW__XU*!,<"`````,=$`OP`````@^'\
M*<H!PH/B_(/Z!`^"(OW__X/B_#'`QP0!`````(/`!#G0<O+I"OW__X"\)"X!
M``!!#X6#^?__@+PD+P$``$,/A77Y__^`O"0P`0``2`^%9_G__X"\)#$!``!%
M#X59^?__:@)J_VK&BW0D*%;H:;C__X/$#&HIBWPD'%=6Z#FW__^-A1"3__]0
MC87<DO__5_]T)"C_="0H4&K_:@'_="1$Z*6Z__^#Q##I^_?__Y"-="8`,<EF
MB4P"_NEU_/__Z+<$``"-M"8`````55=64^@7O?__@<-S<P``@^PXBZL(`0``
M9:$4````B40D*#'`_W4`Z`2Z__]?_W4`B<;H^;G__P^V0&B(1FF-1"0HB40D
M'(G"C8/SD?__Z)WC__^#Q!"%P'0)@#@Q#X1]`@``Z/CN__^#[`S_=0#HO;G_
M_XV3"I/__VH+:@%24.C<M___@\0@A<`/A+(```"+0`R#NWP1```!BT`8B40D
M!`^.FP```#'_O@$```#K+9"+0@R#[`A0BX-X$0``_S2PZ!NV__^#Q!"%P'5D
MBX-\$0``@\8!@\<!.?!^6H/L#/]U`.A)N?__:@!7_W0D'%#HS+C__X/$((7`
M=#6+$(M"""4`!"``/0`$``!TI(E4)`B#[`S_=0#H%;G__VH":@"+5"0@4E#H
MMK;__X/$(.N$D(N#?!$``(U0_SGZ#X1?`0``@^P,_W4`Z.2X__^-DP^3__]J
M`VH!4E#H`[?__X/$((7`B<9T,XM`#(/L#(LX_W4`Z+JX__^-DQ&3__^#Q`Q2
M5U#H2;;__XM&#(/$$(LP]D8*0`^%L`$``(/L#/]U`.B,N/__C9,6D___:@-J
M`5)0Z*NV__^#Q""%P(G&=#>+5"0,C8/!D?__Z"/B__^%P(G'#X1)`0``BT8,
M@^P,BS#_=0#H2;C__X/$#%=64.C>M?__@\00@^P,_W4`Z#"X__^-DQB3__^#
MQ`QJ`5)0Z,ZV__^)QEC_=0#H$[C__XV3+9/__X/$#%)64.BBM?__6O]U`.CY
MM___BU0D',9`:0"-@[B1___HIN'__X/$$(7`B<:)@X`1```/A),```"#[`AH
MP`$``%;HI;;__XU0`8/$$(/Z`78)@_@1#X7K````BT0D'&4S!10````/A=4`
M``"#Q"Q;7E]=PY"-M"8`````@_@!#XZ8_O__BWPD!+X!````C;8`````@^P,
M_W4`@\8!Z&JW__]:65=0Z'&T__^#Q!`YLWP1``!_WNEB_O__D(!X`0`/A'[]
M___I=/W__Y"#[`S_LW@1``#HTN___X/$$(7`B<:)@X`1```/A4S___^-@_R3
M__^#[`Q0Z-"U__^+@W@1``"#[`R+.(M&#(LP_W4`Z/BV__^)^HGPZ(_F__^#
MQ!#IK/[__X/L#/]U`.C<MO__65]64.@#MO__@\00Z33^___H1@$``%"+@W@1
M``!6_S"-@R"4__]0Z'"U__]75E.+="00Z)2Y__^!P_!O``"#[`Q6Z-7J__\/
MM@B#Q!"$R71(C5`!B<>-M@````"`^2\/M@H/1/J#P@&$R77PZ&OM__^%]G0@
MA<!T'(`^`'07C8/$DO__@^P(4%?H[K+__X/$$#GX=`A;7E_#B<?KSUN)\%Y?
MZ:7C__^++"3#D%/H&KG__X'#=F\``(/L"(V#.`$``(7`=!^+`%#_="0<_W0D
M'/]T)!SHT[/__X/$&%O#C;8`````,<#KWV:09I!55U93Z->X__^!PS-O``"#
M[`R+;"0@C;/8_O__Z#NR__^-@]3^__\IQL'^`H7V="4Q_XVV`````(/L!/]T
M)"S_="0L5?^4N]3^__^#QP&#Q!`Y_G7C@\0,6UY?7<.-=@#SPV:09I!FD&:0
M9I!FD&:04^AJN/__@</&;@``@^P(Z+RR__]3@^P(Z%.X__^!PZ]N``"#Q`A;
MPP,````!``(`)7,O)7,`+W!R;V,O<V5L9B]E>&4`1'EN84QO861E<CHZ8F]O
M=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S
M`"X`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"
M`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`
M4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)5
M1P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-
M4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,1%],24)205)97U!!
M5$@`55-%4@!365-414T`+W1M<`!414U01$E2`%1-4`!54T523D%-10`E,#)X
M`'!A<BT`)7,E<R5S)7,`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T
M96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;``P`%!!4CHZ
M4&%C:V5R.CI615)324].`#$N,#,W`"UE`"TM`````%]?14Y67U!!4E]#3$5!
M3E]?("`@("`@("`@("`@("`@`````'!E<FQX<VDN8P```"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I
M*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L
M96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%5N
M86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R
M<FYO/25I*0H`````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D
M>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L
M;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L
M($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U
M:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I
M<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@
M(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@
M+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P
M87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G
M*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M
M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D
M:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@
M)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O
M"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[
M('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*
M<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M
M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D
M978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U
M=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C
M;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN
M=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI0
M05(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@
M(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@
M("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G
M(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_
M("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E
M;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)
M1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M
M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE(#T@
M+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X(#T@+3$[
M"G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T(#X@)'-I
M>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E:R!F86EL
M960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A9"!?1D@L
M("1B=68L("1O9F9S970["F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B)'!R;V=N
M86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED>"`](')I
M;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL87-T(&EF("1I9'@@/CT@,"!\
M?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q,#(T.PHD
M;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD;V9F<V5T
M("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O9F9S970L(#(["G)E860@7T9(
M+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S970@+2!U;G!A8VLH(DXB+"`D
M8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT96QL
M(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B
M1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ
M<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@
M*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N
M9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO
M*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N
M9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA
M;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]
M"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE
M*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D
M9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M
M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*
M8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*
M?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B![
M"FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D
M=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I
M<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME
M>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D
M+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K
M97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM0
M05)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E
M*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@
M,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T
M96UP9FEL92@B)&9I;&5N86UE+3Y[8W)C?2YP;2(L("1F:6QE;F%M92T^>V)U
M9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG
M="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D
M9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@
M)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U
M:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H
M<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD
M9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I
M;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*
M96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E
M8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I
M;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*
M)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.
M5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q
M("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@
M<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS
M=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`
M05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6
M.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![
M(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL
M92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI
M*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?
M:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B([
M"GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q
M(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G
M0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*
M)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H
M+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2([
M"GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H
M:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*
M?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*
M>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM
M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D
M<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*
M;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D
M<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE
M)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N
M=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N
M=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M
M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK
M*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM
M;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S
M(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%
M050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)5
M3D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H
M9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K
M(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D
M14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E
M;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O
M<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E
M;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^
M("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI
M("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L
M(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@
M*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F
M:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2![
M"G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN
M8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I
M=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N
M9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,[
M"FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?
M<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#
M;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@
M*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A
M8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O
M7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@
M/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H
M+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D
M=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*
M;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I
M(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D
M969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@
M:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O
M.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D
M9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT
M.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*
M?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@
M;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&
M24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M
M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)
M37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H
M+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@
M07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD
M9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N
M9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE
M7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@
M/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W
M('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%
M4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D
M<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@
M(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY
M("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE
M*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D
M8W1X+3YH97AD:6=E<W0@.B`D;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP
M(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X]
M(")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H
M+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U
M+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?
M<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E
M86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M
M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R
M+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*
M+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E
M;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B
M:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA
M;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M
M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=
M(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N
M<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S
M:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@
M0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P
M871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L
M("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM
M:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@
M=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI
M8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I
M<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E
M<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N
M;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97([
M"G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*
M<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER
M92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A
M;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V
M86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!
M<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(
M87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R
M97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@
M?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T
M96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D
M14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!4
M35`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D
M=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I
M9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,
M;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*
M?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED
M.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6
M>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*
M;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A
M8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF
M("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O
M9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*
M<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF
M("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R
M96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM
M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ
M4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[
M($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@
M979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]
M"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE
M(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E
M*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M
M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L
M;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]4
M14U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*
M?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA
M;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D
M<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D
M=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@
M)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2([
M"F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@[
M"F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N
M86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE
M*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G
M;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P
M96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H
M.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N
M86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@
M)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%4
M2'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@
M97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM
M?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M
M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?
M9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!2
M3T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D
M.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS
M,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@
M/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I
M9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]
M"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%
M1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)
M04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%
M0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["F1E;&5T92`D
M14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@
M1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,
M7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY
M("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,
M14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]
M*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T
M:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]
M?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I
M9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*
M?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q
M=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O
M;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S
M:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB
M97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`
M24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD[
M"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G
M;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE
M("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H
M)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT[
M"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H
M)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?
M7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*``$;`SOP````'0``
M`*QR__\,`0``?';__S`!``",=O__L`T``#QZ__]$`0``W)___X@!``"LH/__
M[`$``#RA__\D`@``C*/__Z0"```<I?__7`,``+RE___,`P``C*;__V@$``#,
MIO__F`0``"RG___D!```_*?__W@%```,J/__C`4``"RJ__^(!@``7*K__YP&
M``!,J___$`<``!RM__](!P``G*W__VP'``#<K?__F`<``+RN__\$"```[+O_
M_^P+``!LO___8`T``.>____X#0``[+___PP.```LP/__0`X``(S`__^,#@``
MG,#__Z`.```4``````````%Z4@`!?`@!&PP$!(@!```@````'````)AQ___0
M`P````X(1@X,2@\+=`1X`#\:.RHR)"(0````0````$1U__\0`````````$``
M``!4````\'C__Y@E````00X(A0)!#@R'`T0.$(8$00X4@P5&#J`&`X$E"@X4
M0<,.$$'&#@Q!QPX(0<4.!$$+````8````)@```!,GO__R0````!!#@B%`D$.
M#(<#00X0A@1!#A2#!4X.,`)9#C1!#CA$#CQ!#D!(#C!7"@X40\,.$$'&#@Q!
MQPX(0<4.!$H+7@H.%$/##A!!Q@X,0<<."$'%#@1!"S0```#\````N)[__XH`
M````00X(AP)!#@R&`T,.$(,$3@X@`FX*#A!!PPX,0<8."$''#@1!"P``?```
M`#0!```0G___00(```!!#@B%`D$.#(<#0PX0A@1!#A2#!5`.3%<.4$@.0%D.
M3$,.4$@.0`)/#DQ-#E!(#D`">`H.%$'##A!!Q@X,0<<."$'%#@1'"P)8#DA!
M#DQ!#E!,#D!Q#DQ+#E!(#D!.#D1!#DA)#DQ%#E!0#D````"T````M`$``."@
M__^&`0```$$."(4"00X,AP-!#A"&!$$.%(,%4PZ@`6P*#A1!PPX00<8.#$''
M#@A!Q0X$20M##JP!00ZP`4@.H`%?#JP!00ZP`4@.H`%[#JP!00ZP`6L.K`%!
M#J@!10ZL`4$.L`%$#K0!0@ZX`4(.O`%!#L`!2`ZD`40.J`%!#JP!0@ZP`4@.
MH`%8#JP!00ZP`4@.H`%##JP!00ZP`4@.H`%<#JP!00ZP`5`.H`$`;````&P"
M``"XH?__F`````!!#@B'`D$.#(8#0PX0@P1.#AQ(#B!(#A1&#AA!#AQ"#B!(
M#A!%"L,.#$/&#@A!QPX$0PM##AQ"#B!.#A!/#AQ"#B!.#A!/#AA"#AQ!#B!(
M#A!&PPX,1,8."$''#@0``)@```#<`@``Z*'__]``````00X(A0)!#@R'`T,.
M$(8$00X4@P51#L0@6`[(($L.S"!!#M`@2`[`(%,.Q"!!#L@@0@[,($$.T"!(
M#L`@30[,($(.T"!&#M0@00[8($$.W"!!#N`@2`[`(%8*#A1!PPX00<8.#$''
M#@A!Q0X$1`M1#LP@0@[0($@.Q"!$#L@@00[,($$.T"!(#L`@`"P```!X`P``
M'*+__SL`````00X(@P).#AQ(#B!,#B1,#BA!#BQ!#C!(#@A!PPX$`$@```"H
M`P``+*+__U,`````00X(A@)!#@R#`TX.'$@.($X.'$(.($8.'$<.&$(.'$$.
M($$.)$<.*$<.+$$.,$@.#$'##@A!Q@X$``"0````]`,``$"B___)`````$$.
M"(4"00X,AP-!#A"&!$$.%(,%40ZP0%T.N$!!#KQ`00[`0$<.Q$!%#LA`0@[,
M0$4.T$!(#K!`1PZT0$4.N$!(#KQ`00[`0$@.L$!,#KQ`00[`0$@.L$!)#K1`
M00ZX0$$.O$!!#L!`3`ZP0%@*#A1!PPX00<8.#$''#@A!Q0X$2PL`$````(@$
M``!\HO__!0````````#X````G`0``'BB__\=`@```$$."(4"00X,AP-!#A"&
M!$$.%(,%40[`('0.R"!$#LP@00[0($@.P"!P"@X40<,.$$'&#@Q!QPX(0<4.
M!$$+0P[,($0.T"!&#LP@00[(($T.S"!!#M`@30[`(&@.R"!!#LP@00[0($@.
MP"!+#LP@00[0($@.P"!T#L0@1`[(($$.S"!'#M`@00[4($4.V"!"#MP@10[@
M($@.S"!&#M`@2`[$($8.R"!!#LP@0@[0($@.P"!'#LP@0@[0($X.P"!/#L@@
M1`[,($(.T"!(#L`@`DD.R"!"#LP@00[0($@.P"!4#LP@00[0($@.P"`0````
MF`4``)RC__\B`````````'````"L!0``N*/__^P`````00X(A@)!#@R#`TX.
M(%8.+$$.,$P.('@.+$(.,$@.($\*#@Q!PPX(0<8.!$H+80XD00XH00XL1PXP
M2`X@10H.#$'##@A!Q@X$1PM#"@X,0\,."$'&#@1!"TD.+$$.,$@.(```-```
M`"`&```TI/__R0$```!!#@B'`D$.#(8#00X0@P1.#D`#8`$*#A!!PPX,0<8.
M"$''#@1$"P`@````6`8``,RE__]Y`````$$."(,"3@X@9PH."$'##@1)"P`H
M````?`8``"BF__\T`````$$."(,"3@X02`X<00X@2`X020H."$'##@1&"V@`
M``"H!@``/*;__]@`````00X(A0)!#@R'`T$.$(8$00X4@P5.#C!M#CA!#CQ!
M#D!(#C!4"@X40<,.$$'&#@Q!QPX(0<4.!$<+6PX\00Y`9@XT00XX00X\1PY`
M00Y$0@Y(0@Y,00Y03@XP`.0#```4!P``L*;__RD-````00X(A0)!#@R'`T$.
M$(8$00X4@P51#M""`@+"#MR"`D,.X(("6`[0@@)<#MR"`D8.X(("1`[D@@)"
M#NB"`D(.[(("00[P@@)+#M""`G\.W(("0P[@@@)(#M""`FP.W(("00[@@@)*
M#M""`E0.W(("0P[@@@)(#M""`G\.W(("2`[@@@)5#N2"`D$.Z(("2P[L@@)'
M#O""`D,.](("0@[X@@)"#OR"`D$.@(,"2`[8@@)%#MR"`D$.X(("2`[0@@)2
M#MR"`D0.X(("2`[4@@)&#MB"`D0.W(("0@[@@@),#M""`DL.W(("1@[@@@)&
M#N2"`D<.Z(("2`[L@@)"#O""`D@.T(("9@H.%$'##A!!Q@X,0<<."$'%#@1+
M"U,.V(("00[<@@)$#N""`D8.Y(("1P[H@@)(#NR"`D(.\(("2`[0@@)4#MR"
M`D(.X(("3@[0@@)3#MR"`D(.X(("5P[0@@),#MR"`D(.X(("3@[0@@)3#MR"
M`D,.X(("6P[0@@)+#MR"`D,.X(("1@[<@@)!#MB"`D$.W(("1@[@@@),#M""
M`DL.W(("1P[@@@)(#M""`GX.V(("1`[<@@)$#N""`DP.T((";0[4@@)!#MB"
M`DH.W(("1`[@@@)!#N2"`D(.Z(("0@[L@@)$#O""`D@.T(("<@[<@@)$#N""
M`D$.Y(("00[H@@)$#NR"`D0.\(("1`[T@@)"#OB"`D(._(("00Z`@P)(#M""
M`D,.V(("1P[<@@)!#N""`D@.T(("2`[<@@)&#N""`F$.T(("2P[<@@)##N""
M`EP.T(("=`[<@@)##N""`D@.T(("3@[<@@)*#N""`DP.T(("6P[4@@)"#MB"
M`D(.W(("10[@@@)(#M2"`D(.V(("3`[<@@)!#N""`D@.T(("6@[4@@)"#MB"
M`D0.W(("1`[@@@("K0[0@@):#M2"`D4.V(("1`[<@@)$#N""`DP.T(("`I8.
MU(("00[8@@)$#MR"`D$.X(("7`[0@@(##P$.U(("00[8@@)!#MR"`D0.X(("
M4P[0@@)[#MR"`D0.X(("`D(.T(("`PP"#MR"`D,.X(("1`[D@@)"#NB"`D(.
M[(("00[P@@)+#M""`E<.U(("2@[8@@)$#MR"`D0.X(("00[D@@)"#NB"`D(.
M[(("1`[P@@)(#M""`E<.W(("0P[@@@),#M""`@+9#M2"`D(.V(("0@[<@@)%
M#N""`D@.U(("0@[8@@)%#MR"`D$.X(("3`[D@@)'#NB"`D0.[(("1`[P@@)!
M#O2"`D(.^(("0@[\@@)$#H"#`D@.T(("``!P`0``_`H``/BO__^``P```$$.
M"(4"00X,AP-!#A"&!$$.%(,%3@Y,50Y01@Y,0PY09@Y`50Y,0PY030Y40@Y8
M00Y<00Y@2`Y`;PY(00Y,20Y02`Y`5PY,0PY01PY400Y81`Y<00Y@2`Y`7`Y,
M0PY01PY40@Y810Y<00Y@2`Y`5PY,0PY030Y40@Y800Y<00Y@2`Y`3`Y,10Y0
M3@Y$00Y(00Y,00Y02PY`3PY,0PY030Y40@Y800Y<00Y@2`Y`90Y,10Y02`Y$
M00Y(00Y,00Y02`Y`0PY,0PY03@Y$0@Y(00Y,00Y02`Y,0PY03@Y$00Y(00Y,
M00Y01@Y,0PY06PY`4PY(10Y,00Y02PY`8@H.%$'##A!!Q@X,0<<."$'%#@1)
M"UL.3$,.4$D.3$$.2$$.3$$.4$@.0&$*#DQ&#E!(#D!9#DQ!#E!%"TD.3$H.
M4%$.0$@.3$,.4$8.3$$.2$$.3$$.4$@.0$L.1$<.2$(.3$<.4`!,````<`P`
M``2R__][`````$$."(<"00X,A@-!#A"#!%(.'$$.($L.$'H.&$$.'$$.($@.
M$$4*PPX,0<8."$''#@1!"T7##@Q#Q@X(0<<.!$0```#`#```U&C__T`"````
M1`P!`$<0!0)U`$8/`W5P!A`'`G5\$`8"=7@0`P)U=`-[`0K!#`$`0<-!QD''
M0<5##`0$00L``!`````(#0``Y['__P0`````````,````!P-``#8L?__/```
M``!!#@B#`DX.$$T.%$0.&$0.'$0.($@."$'##@1'#A"#`@```$@```!0#0``
MY+'__UT`````00X(A0)!#@R'`T$.$(8$00X4@P5.#B!I#B1$#BA$#BQ!#C!-
M#B!'#A1!PPX00<8.#$''#@A!Q0X$```0````G`T``/BQ__\"`````````!@`
M``"P#0``]+'__Q0`````00X(@P).#A``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````&`9```0&0``````
M``$````!`````0```-\!```!````Z@$```$```#T`0```0```$,"```!````
MH`,```P```#L$0``#0```!1@```9````H,T``!L````$````&@```*3-```<
M````!````/7^_V^L`0``!0```/P(```&````C`(```H````2!0``"P```!``
M```5``````````,```#,S@```@```.`!```4````$0```!<````,$```$0``
M`'P/```2````D````!,````(````'@````@```#[__]O`0``"/[__V_<#@``
M____;P(```#P__]O#@X``/K__V\%````````````````````````````````
M`````````````````````````*S-`````````````"82```V$@``1A(``%82
M``!F$@``=A(``(82``"6$@``IA(``+82``#&$@``UA(``.82``#V$@``!A,`
M`!83```F$P``-A,``$83``!6$P``9A,``'83``"&$P``EA,``*83``"V$P``
MQA,``-83``#F$P``]A,```84```6%```)A0``#84``!&%```5A0``&84``!V
M%```AA0``)84``"F%```MA0``,84``#6%```YA0``/84```&%0``%A4``"85
M```V%0``1A4``%85``!F%0``=A4``(85``"6%0``IA4``+85``#&%0``UA4`
M`````````````````````````````````````````````````/`5````````
M``````````````````````30``#_____,&,``$=#0SH@*$1E8FEA;B`V+C0N
M,"TR*2`V+C0N,"`R,#$W,#<R-```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N
M04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`
M+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`
M+G)E;"YP;'0`+FEN:70`+G!L="YG;W0`+G1E>'0`+F9I;FD`+G)O9&%T80`N
M96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A
M>0`N:F-R`"YD>6YA;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`````````````
M````````````````````````````````````````````"P````$````"````
M5`$``%0!```3```````````````!`````````!,````'`````@```&@!``!H
M`0``(```````````````!``````````A````!P````(```"(`0``B`$``"0`
M``````````````0`````````-````/;__V\"````K`$``*P!``#@````!0``
M```````$````!````#X````+`````@```(P"``",`@``<`8```8````!````
M!````!````!&`````P````(```#\"```_`@``!(%``````````````$`````
M````3@```/___V\"````#@X```X.``#.````!0`````````"`````@```%L`
M``#^__]O`@```-P.``#<#@``H`````8````"````!`````````!J````"0``
M``(```!\#P``?`\``)`````%``````````0````(````<P````D```!"````
M#!````P0``#@`0``!0```!<````$````"````'P````!````!@```.P1``#L
M$0``(P``````````````!`````````!W`````0````8````0$@``$!(``-`#
M`````````````!`````$````@@````$````&````X!4``.`5```0````````
M```````(````"````(L````!````!@```/`5``#P%0``)$H`````````````
M$`````````"1`````0````8````48```%&```!0```````````````0`````
M````EP````$````"````*&```"A@```\/P`````````````$`````````)\`
M```!`````@```&2?``!DGP``]```````````````!`````````"M`````0``
M``(```!8H```6*```,P-``````````````0`````````MP````X````#````
MH,T``*"]```$```````````````$````!````,,````/`````P```*3-``"D
MO0``!```````````````!`````0```#/`````0````,```"HS0``J+T```0`
M``````````````0`````````U`````8````#````K,T``*R]```@`0``!@``
M```````$````"````(8````!`````P```,S.``#,O@``-`$`````````````
M!`````0```#=`````0````,`````T````,```!````````````````0`````
M````XP````@````#````(-```!#````T$``````````````@`````````.@`
M```!````,``````````0P```)0```````````````0````$````!`````P``
A````````````-<```/$```````````````$`````````
